Index: src/ia32/lithium-codegen-ia32.cc |
diff --git a/src/ia32/lithium-codegen-ia32.cc b/src/ia32/lithium-codegen-ia32.cc |
index ed5bd47a403101735846ab11fefd8e08fa670594..8e90db83c31933b9fb4bd44bb88875614eaeb9d9 100644 |
--- a/src/ia32/lithium-codegen-ia32.cc |
+++ b/src/ia32/lithium-codegen-ia32.cc |
@@ -175,11 +175,11 @@ bool LCodeGen::GeneratePrologue() { |
} |
#endif |
// Classic mode functions and builtins need to replace the receiver with the |
// global proxy when called as functions (without an explicit receiver |
// object). |
if (info_->this_has_uses() && |
- info_->is_classic_mode() && |
+ info_->is_sloppy_mode() && |
!info_->is_native()) { |
Label ok; |
// +1 for return address. |
@@ -3394,7 +3394,7 @@ void LCodeGen::DoLoadKeyedExternalArray(LLoadKeyed* instr) { |
case FAST_HOLEY_ELEMENTS: |
case FAST_HOLEY_DOUBLE_ELEMENTS: |
case DICTIONARY_ELEMENTS: |
- case NON_STRICT_ARGUMENTS_ELEMENTS: |
+ case SLOPPY_ARGUMENTS_ELEMENTS: |
UNREACHABLE(); |
break; |
} |
@@ -4506,7 +4506,7 @@ void LCodeGen::DoStoreKeyedExternalArray(LStoreKeyed* instr) { |
case FAST_HOLEY_ELEMENTS: |
case FAST_HOLEY_DOUBLE_ELEMENTS: |
case DICTIONARY_ELEMENTS: |
- case NON_STRICT_ARGUMENTS_ELEMENTS: |
+ case SLOPPY_ARGUMENTS_ELEMENTS: |
UNREACHABLE(); |
break; |
} |
@@ -175,11 +175,11 @@ bool LCodeGen::GeneratePrologue() { |
} |
#endif |
- // Classic mode functions and builtins need to replace the receiver with the |
+ // Sloppy mode functions and builtins need to replace the receiver with the |
// global proxy when called as functions (without an explicit receiver |
// object). |